.. image:: imgs/spyql_logo.png
  :width: 250
  :alt: SPyQL - SQL with Python in the middle


SQL with Python in the middle
================================================

Welcome to `SPyQL <https://github.com/dcmoura/spyql>`_'s documentation!

.. toctree::
   :maxdepth: 1

   readme
   distinctive
   installation
   hello
   queries
   differences
   reference
   import
   recipes
   contributing
   authors
   history
